@@ -17,6 +17,7 @@ PRECOMPILED_DATA_FIELDS = ["abi", "bin", "bin-runtime", "metadata"]
 CONTRACT_HUMAN_STANDARD_TOKEN = "HumanStandardToken"
 CONTRACT_TOKEN_NETWORK_REGISTRY = "TokenNetworkRegistry"
 CONTRACT_TOKEN_NETWORK = "TokenNetwork"
+LIBRARY_TOKEN_NETWORK_UTILS = "TokenNetworkUtils"
 CONTRACT_SECRET_REGISTRY = "SecretRegistry"
 CONTRACT_CUSTOM_TOKEN = "CustomToken"
 CONTRACT_CUSTOM_TOKEN_NO_DECIMALS = "CustomTokenNoDecimals"
@@ -27,6 +28,9 @@ CONTRACT_USER_DEPOSIT = "UserDeposit"
 CONTRACT_ONE_TO_N = "OneToN"
 CONTRACT_DEPOSIT = "Deposit"
 
+# IDs for linking
+LIBRARY_TOKEN_NETWORK_UTILS_LINK_KEY = "data/source/lib/TokenNetworkUtils.sol:TokenNetworkUtils"
+
 # Timeouts
 TEST_SETTLE_TIMEOUT_MIN = 5
 TEST_SETTLE_TIMEOUT_MAX = 100000
@@ -142,6 +146,7 @@ class DeploymentModule(Enum):
 START_QUERY_BLOCK_KEY = "DefaultStartBlock"
 
 ID_TO_CHAINNAME: Dict[ChainID, str] = {
+    ChainID(-5): "goerli_unstable",
     ChainID(1): "mainnet",
     ChainID(3): "ropsten",
     ChainID(4): "rinkeby",
