@@ -42,7 +42,8 @@ def validate_contract_name(_ctx: Context, _param: Any, value: Optional[str]) ->
 @click.option("--chain-id", default=3, help="Chain id. E.g. --chain-id 3")
 @click.option("--apikey", required=True, help="A valid Etherscan APIKEY is required.")
 @click.option(
-    "--guid", help="GUID from a previous verification attempt. Tries to get the submission status."
+    "--guid",
+    help="GUID from a previous verification attempt. Tries to get the submission status.",
 )
 @click.option(
     "--contract-name",
@@ -55,7 +56,7 @@ def etherscan_verify(
     chain_id: ChainID, apikey: str, guid: Optional[str], contract_name: Optional[str]
 ) -> None:
     if guid:
-        guid_status(etherscan_api=api_of_chain_id[chain_id], guid=guid)
+        guid_status(etherscan_api=api_of_chain_id[chain_id], guid=guid, apikey=apikey)
         return
 
     for list_entry in CONTRACT_LIST:
@@ -106,7 +107,7 @@ api_of_chain_id = {
 
 
 def join_sources(source_module: DeploymentModule, contract_name: str) -> str:
-    """ Use join_contracts.py to concatenate all imported Solidity files.
+    """Use join_contracts.py to concatenate all imported Solidity files.
 
     Args:
         source_module: a module name to look up contracts_source_path()
@@ -138,7 +139,9 @@ def join_sources(source_module: DeploymentModule, contract_name: str) -> str:
 
 
 def get_constructor_args(
-    deployment_info: DeployedContracts, contract_name: str, contract_manager: ContractManager
+    deployment_info: DeployedContracts,
+    contract_name: str,
+    contract_manager: ContractManager,
 ) -> str:
     constructor_arguments = deployment_info["contracts"][contract_name]["constructor_arguments"]
     if constructor_arguments != []:
@@ -211,7 +214,7 @@ def etherscan_verify_contract(
     retries = 10
     while status == "0" and retries > 0:
         retries -= 1
-        r = guid_status(etherscan_api=etherscan_api, guid=guid)
+        r = guid_status(etherscan_api=etherscan_api, guid=guid, apikey=apikey)
         status = r["status"]
         if r["result"] == "Fail - Unable to verify":
             raise ValueError(manual_submission_guide)
@@ -223,9 +226,12 @@ def etherscan_verify_contract(
 
 
 def _verify_singleton_contract(
-    chain_id: ChainID, apikey: str, source_module: DeploymentModule, contract_name: str,
+    chain_id: ChainID,
+    apikey: str,
+    source_module: DeploymentModule,
+    contract_name: str,
 ) -> None:
-    """ Calls Etherscan API for verifying the Solidity source of a contract.
+    """Calls Etherscan API for verifying the Solidity source of a contract.
 
     This function can only be used to verify contracts which are only deployed
     once. E.g. `TokenNetworkRegistry`, but not `TokenNetwork`.
@@ -256,8 +262,13 @@ def _verify_singleton_contract(
     )
 
 
-def guid_status(etherscan_api: str, guid: str) -> Dict:
-    data = {"guid": guid, "module": "contract", "action": "checkverifystatus"}
+def guid_status(etherscan_api: str, guid: str, apikey: str) -> Dict:
+    data = {
+        "guid": guid,
+        "module": "contract",
+        "action": "checkverifystatus",
+        "apikey": apikey,
+    }
     r = requests.get(etherscan_api, data, headers={"User-Agent": USER_AGENT})
     try:
         status_content = json.loads(r.content.decode())
