@@ -11,7 +11,6 @@ from web3.contract import Contract
 from raiden_contracts.constants import (
     CONTRACT_MONITORING_SERVICE,
     LOCKSROOT_OF_NO_LOCKS,
-    TEST_SETTLE_TIMEOUT_MIN,
     MessageTypeId,
     MonitoringServiceEvent,
 )
@@ -37,7 +36,8 @@ def ms_address(
     # register MS in the ServiceRegistry contract
     call_and_transact(custom_token.functions.mint(2 * SERVICE_DEPOSIT), {"from": ms})
     call_and_transact(
-        custom_token.functions.approve(service_registry.address, SERVICE_DEPOSIT), {"from": ms}
+        custom_token.functions.approve(service_registry.address, SERVICE_DEPOSIT),
+        {"from": ms},
     )
     call_and_transact(service_registry.functions.deposit(SERVICE_DEPOSIT), {"from": ms})
 
@@ -57,7 +57,7 @@ def setup_monitor_data(
 ) -> Callable:
     def f(monitoring_service_contract: Contract) -> Dict:
         # Create two parties and a channel between them
-        (A, B) = get_accounts(2, privkeys=["0x" + "1" * 64, "0x" + "2" * 64])
+        (A, B) = get_accounts(2, privkeys=[bytes([1] * 32), bytes([2] * 32)])
         deposit_to_udc(B, REWARD_AMOUNT)
         channel_identifier = create_channel(A, B)[0]
 
@@ -95,20 +95,21 @@ def setup_monitor_data(
         # close channel
         call_and_transact(
             token_network.functions.closeChannel(
-                channel_identifier, B, A, *balance_proof_A._asdict().values(), closing_signature_A
+                channel_identifier,
+                B,
+                A,
+                *balance_proof_A._asdict().values(),
+                closing_signature_A,
             ),
             {"from": A},
         )
 
         # calculate when this MS is allowed to monitor
-        (settle_block_number, _) = token_network.functions.getChannelInfo(
-            channel_identifier, A, B
-        ).call()
-        first_allowed = monitoring_service_contract.functions.firstBlockAllowedToMonitor(
-            closed_at_block=settle_block_number - TEST_SETTLE_TIMEOUT_MIN,
-            settle_timeout=TEST_SETTLE_TIMEOUT_MIN,
-            participant1=A,
-            participant2=B,
+        first_allowed = monitoring_service_contract.functions.firstBlockAllowedToMonitorChannel(
+            token_network=token_network.address,
+            channel_identifier=channel_identifier,
+            closing_participant=A,
+            non_closing_participant=B,
             monitoring_service_address=ms_address,
         ).call()
 
@@ -153,7 +154,7 @@ def test_claimReward_with_settle_call(
     channel_identifier = monitor_data["channel_identifier"]
 
     # wait until MS is allowed to monitor
-    mine_blocks(web3, monitor_data["first_allowed"] - web3.eth.blockNumber)
+    mine_blocks(web3, monitor_data["first_allowed"] - web3.eth.block_number)
 
     # MS updates closed channel on behalf of B
     txn_hash = call_and_transact(
@@ -208,7 +209,11 @@ def test_claimReward_with_settle_call(
     ms_ev_handler.assert_event(
         txn_hash,
         MonitoringServiceEvent.REWARD_CLAIMED,
-        dict(ms_address=ms_address, amount=REWARD_AMOUNT, reward_identifier=reward_identifier),
+        dict(
+            ms_address=ms_address,
+            amount=REWARD_AMOUNT,
+            reward_identifier=reward_identifier,
+        ),
     )
 
     # Check that MS balance has increased by claiming the reward
@@ -243,7 +248,7 @@ def test_monitor(
 
     # monitoring too early must fail
     with pytest.raises(TransactionFailed, match="not allowed to monitor"):
-        assert web3.eth.blockNumber < monitor_data["first_allowed"]
+        assert web3.eth.block_number < monitor_data["first_allowed"]
         txn_hash = call_and_transact(
             monitoring_service_external.functions.monitor(
                 A,
@@ -258,7 +263,7 @@ def test_monitor(
         )
 
     # wait until MS is allowed to monitor
-    mine_blocks(web3, monitor_data["first_allowed"] - web3.eth.blockNumber)
+    mine_blocks(web3, monitor_data["first_allowed"] - web3.eth.block_number)
 
     # successful monitor call
     txn_hash = call_and_transact(
@@ -300,9 +305,9 @@ def test_monitor_by_unregistered_service(
     A, B = monitor_data["participants"]
 
     # wait until MS is allowed to monitor
-    mine_blocks(web3, monitor_data["first_allowed"] - web3.eth.blockNumber)
+    mine_blocks(web3, monitor_data["first_allowed"] - web3.eth.block_number)
 
-    # only registered service provicers may call `monitor`
+    # only registered service providers may call `monitor`
     with pytest.raises(TransactionFailed, match="service not registered"):
         monitoring_service_external.functions.monitor(
             A,
@@ -339,7 +344,7 @@ def test_monitor_on_wrong_token_network_registry(
     A, B = monitor_data["participants"]
 
     # wait until MS is allowed to monitor
-    mine_blocks(web3, monitor_data["first_allowed"] - web3.eth.blockNumber)
+    mine_blocks(web3, monitor_data["first_allowed"] - web3.eth.block_number)
 
     # monitor() call fails because the TokenNetwork is not registered on the
     # supposed TokenNetworkRegistry
@@ -398,7 +403,7 @@ def test_updateReward(
     assert monitoring_service_internals.functions.rewardNonce(reward_identifier).call() == 3
 
 
-def test_firstAllowedBlock(monitoring_service_external: Contract) -> None:
+def test_pureFirstAllowedBlock(monitoring_service_external: Contract) -> None:
     def call(addresses: List[int], closed_at_block: int = 1000, settle_timeout: int = 100) -> int:
         first_allowed = monitoring_service_external.functions.firstBlockAllowedToMonitor(
             closed_at_block=closed_at_block,
@@ -499,10 +504,10 @@ def test_monitoring_service_deploy_with_service_registry_without_code(
     uninitialized_user_deposit_contract: Contract,
     token_network_registry_contract: Contract,
 ) -> None:
-    """ Test MonitoringService's constructor with a service_registry address
+    """Test MonitoringService's constructor with a service_registry address
 
     which does not contain code. This is supposed to cause a failure in one
-    of the require() statements in the constructor. """
+    of the require() statements in the constructor."""
     # No good error message is available due to
     # https://github.com/raiden-network/raiden-contracts/issues/1329
     # with pytest.raises(TransactionFailed, match="ServiceRegistry has no code"):
