@@ -12,6 +12,7 @@ from raiden_contracts.constants import (
     CONTRACT_TOKEN_NETWORK,
     CONTRACT_TOKEN_NETWORK_REGISTRY,
     CONTRACT_USER_DEPOSIT,
+    LIBRARY_TOKEN_NETWORK_UTILS,
     TEST_SETTLE_TIMEOUT_MAX,
     TEST_SETTLE_TIMEOUT_MIN,
     MessageTypeId,
@@ -30,6 +31,7 @@ def test_gas_json_has_enough_fields(version: Optional[str]) -> None:
     """ Check is gas.json contains enough fields """
     doc = gas_measurements(version)
     keys = {
+        "TokenNetworkUtils DEPLOYMENT",
         "CustomToken.mint",
         "CustomToken.approve",
         "CustomToken.transfer",
@@ -40,6 +42,9 @@ def test_gas_json_has_enough_fields(version: Optional[str]) -> None:
         "OneToN.bulkClaim 1 ious",
         "OneToN.bulkClaim 6 ious",
         "SecretRegistry.registerSecret",
+        "SecretRegistry.registerSecretBatch1",
+        "SecretRegistry.registerSecretBatch2",
+        "SecretRegistry.registerSecretBatch3",
         "ServiceRegistry.deposit",
         "ServiceRegistry.setURL",
         "TokenNetwork DEPLOYMENT",
@@ -61,18 +66,30 @@ def test_gas_json_has_enough_fields(version: Optional[str]) -> None:
     assert set(doc.keys()) == keys
 
 
+@pytest.fixture
+def print_gas_token_network_utils(
+    deploy_tester_contract_txhash: Callable,
+    print_gas: Callable,
+) -> None:
+    """ Abusing pytest to print the deployment gas cost of TokenNetworkUtils """
+    txhash = deploy_tester_contract_txhash(LIBRARY_TOKEN_NETWORK_UTILS)
+    print_gas(txhash, LIBRARY_TOKEN_NETWORK_UTILS + " DEPLOYMENT")
+
+
 @pytest.fixture
 def print_gas_token_network_registry(
     web3: Web3,
     deploy_tester_contract_txhash: Callable,
     secret_registry_contract: Contract,
+    token_network_libs: Dict,
     print_gas: Callable,
 ) -> None:
     """ Abusing pytest to print the deployment gas cost of TokenNetworkRegistry """
     txhash = deploy_tester_contract_txhash(
         CONTRACT_TOKEN_NETWORK_REGISTRY,
+        libs=token_network_libs,
         _secret_registry_address=secret_registry_contract.address,
-        _chain_id=web3.eth.chainId,
+        _chain_id=web3.eth.chain_id,
         _settlement_timeout_min=TEST_SETTLE_TIMEOUT_MIN,
         _settlement_timeout_max=TEST_SETTLE_TIMEOUT_MAX,
         _max_token_networks=10,
@@ -86,6 +103,7 @@ def print_gas_token_network_deployment(
     get_accounts: Callable,
     print_gas: Callable,
     custom_token: Contract,
+    token_network_libs: Dict,
     secret_registry_contract: Contract,
     deploy_tester_contract_txhash: Callable,
     channel_participant_deposit_limit: int,
@@ -95,9 +113,10 @@ def print_gas_token_network_deployment(
     deprecation_executor = get_accounts(1)[0]
     txhash = deploy_tester_contract_txhash(
         CONTRACT_TOKEN_NETWORK,
+        libs=token_network_libs,
         _token_address=custom_token.address,
         _secret_registry=secret_registry_contract.address,
-        _chain_id=web3.eth.chainId,
+        _chain_id=web3.eth.chain_id,
         _settlement_timeout_min=TEST_SETTLE_TIMEOUT_MIN,
         _settlement_timeout_max=TEST_SETTLE_TIMEOUT_MAX,
         _deprecation_executor=deprecation_executor,
@@ -120,7 +139,9 @@ def print_gas_token_network_create(
     registry = get_token_network_registry(**token_network_registry_constructor_args)
     txn_hash = call_and_transact(
         registry.functions.createERC20TokenNetwork(
-            custom_token.address, channel_participant_deposit_limit, token_network_deposit_limit
+            custom_token.address,
+            channel_participant_deposit_limit,
+            token_network_deposit_limit,
         ),
         {"from": DEPLOYER_ADDRESS},
     )
@@ -135,6 +156,11 @@ def print_gas_secret_registry(secret_registry_contract: Contract, print_gas: Cal
     txn_hash = call_and_transact(secret_registry_contract.functions.registerSecret(secret))
     print_gas(txn_hash, CONTRACT_SECRET_REGISTRY + ".registerSecret")
 
+    for batch_size in (1, 2, 3):
+        batch = [bytes([batch_size, i] + [0] * 30) for i in range(batch_size)]
+        txn_hash = call_and_transact(secret_registry_contract.functions.registerSecretBatch(batch))
+        print_gas(txn_hash, CONTRACT_SECRET_REGISTRY + ".registerSecretBatch" + str(batch_size))
+
 
 @pytest.fixture
 def print_gas_channel_cycle(
@@ -228,7 +254,15 @@ def print_gas_channel_cycle(
     mine_blocks(web3, settle_timeout)
     txn_hash = call_and_transact(
         token_network.functions.settleChannel(
-            channel_identifier, B, 5, locked_amount2, locksroot2, A, 10, locked_amount1, locksroot1
+            channel_identifier,
+            B,
+            5,
+            locked_amount2,
+            locksroot2,
+            A,
+            10,
+            locked_amount1,
+            locksroot1,
         )
     )
     print_gas(txn_hash, CONTRACT_TOKEN_NETWORK + ".settleChannel")
@@ -284,7 +318,8 @@ def print_gas_monitoring_service(
     # register MS in the ServiceRegistry contract
     call_and_transact(custom_token.functions.mint(SERVICE_DEPOSIT * 2), {"from": MS})
     call_and_transact(
-        custom_token.functions.approve(service_registry.address, SERVICE_DEPOSIT), {"from": MS}
+        custom_token.functions.approve(service_registry.address, SERVICE_DEPOSIT),
+        {"from": MS},
     )
     call_and_transact(service_registry.functions.deposit(SERVICE_DEPOSIT), {"from": MS})
 
@@ -372,9 +407,9 @@ def print_gas_one_to_n(
     deposit_to_udc(A, 30)
 
     # happy case
-    chain_id = web3.eth.chainId
+    chain_id = web3.eth.chain_id
     amount = TokenAmount(10)
-    expiration = BlockExpiration(web3.eth.blockNumber + 2)
+    expiration = BlockExpiration(web3.eth.block_number + 2)
     signature = sign_one_to_n_iou(
         get_private_key(A),
         sender=A,
@@ -430,7 +465,7 @@ def print_gas_user_deposit(
     web3: Web3,
     print_gas: Callable,
 ) -> None:
-    """ Abusing pytest to print gas cost of UserDeposit functions
+    """Abusing pytest to print gas cost of UserDeposit functions
 
     The `transfer` function is not included because it's only called by trusted
     contracts as part of another function.
@@ -495,6 +530,7 @@ def print_gas_token(get_accounts: Callable, custom_token: Contract, print_gas: C
 # execution of multiple gas printing tests, you see a corrupted gas.json.
 @pytest.mark.slow
 @pytest.mark.usefixtures(
+    "print_gas_token_network_utils",
     "print_gas_token_network_registry",
     "print_gas_token_network_deployment",
     "print_gas_token_network_create",
